:mod:`euphorie.client.utils`
============================

.. automodule:: euphorie.client.utils

.. autofunction:: HasText

.. autofunction:: setLanguage

.. autofunction:: RelativePath

.. autofunction:: MatchColour(colour, low_l=0.2, high_l=0.65)

.. autofunction:: IsBright


Views
-----

.. autoclass:: WebHelpers
   :members:

.. autoclass:: I18nJSONView
   :members:

.. autoclass:: DefaultIntroduction
   :members:
